<div align="center">

# nonebot-plugin-whateat-pic

_⭐基于Nonebot2的一款今天吃什么喝什么的插件⭐_


</div>


## ⭐ 介绍

一款离线版决定今天吃喝什么的nb2插件，功能及其简单。
由于本人第一次创建，有不足的地方还请指出

## 💿 安装

<details>
<summary>使用 nb-cli 安装</summary>

 在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-whateat-pic
</details>

<details>
<summary>使用 pip 安装</summary>

    pip install nonebot-plugin-whateat-pic
</details>

## ⚙️ 配置

没有配置，有什么美食图片自己拖进去就行

## ⭐ 使用

### 指令：**吃什么，**喝什么
如：
    /今天吃什么、/早上吃什么，/夜宵喝什么
    
**注意**

默认情况下, 您应该在指令前加上命令前缀, 通常是 /

## 🌙 未来
或许添加更多的美食图片吧……